@@ -162,6 +162,11 @@ class History(object):
             self.events
         )
 
+    @property
+    def reversed(self):
+        for i in xrange(len(self.events) - 1, -1, -1):
+            yield self.events[i]
+
     @property
     def distinct(self):
         """Extracts distinct history events based on their types
